﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.IO;


namespace AutoFolderMirror
{
    /// <summary>
    /// 文件克隆帮助类
    /// </summary>
    public class MirrorHelper
    {
        public MirrorHelper() { }
        public MirrorHelper(string _SourceDirPath)
        {
            SourceDirPath = _SourceDirPath;
        }
        /// <summary>
        /// 是否复制文件内容
        /// </summary>
        public bool IsCopyContent { get; set; }
        /// <summary>
        /// 是否创建空白文件
        /// </summary>
        public bool IsNoFile { get; set; } = true;
        /// <summary>
        /// 当文件大小大于这个数，复制内容，否则只镜像路径
        /// </summary>
        public int CriticalFileBytes { get; set; }

        /// <summary>
        /// 需要被镜像的文件夹路径
        /// </summary>
        public string SourceDirPath { get; set; }

        public string TargetDirPath
        {
            get
            {
                DirectoryInfo Source = new DirectoryInfo(SourceDirPath);
                string newName = Source.Name + "-克隆-" + string.Format("{0:x}", DateTime.Now.ToString("yyyy-MM-ddHHmmss")); ;
                return Path.Combine(TargetBaseDirPath, newName);
            }
        }
        public string TargetBaseDirPath = "";
        public string CurrTargetDirPath;
        public void Mirror(string _TargetBaseDirPath)
        {
            TargetBaseDirPath = _TargetBaseDirPath;
            CurrTargetDirPath = TargetDirPath;
            Mirror(SourceDirPath, CurrTargetDirPath);
        }
        /// <summary>
        /// 开始克隆
        /// </summary>
        private void Mirror(string sourceDirPath, string targetDirPath)
        {
            if (!Directory.Exists(targetDirPath))
                Directory.CreateDirectory(targetDirPath);

            string[] dirs = Directory.GetDirectories(sourceDirPath);

            foreach (string dir in dirs)
            {
                DirectoryInfo di = new DirectoryInfo(dir);
                Mirror(dir, Path.Combine(targetDirPath, di.Name));
            }

            string[] files = Directory.GetFiles(sourceDirPath, "*.*", SearchOption.TopDirectoryOnly);

            foreach (string file in files)
            {
                FileInfo fi = new FileInfo(file);
                string newfile = Path.Combine(targetDirPath, fi.Name);

                if (IsCopyContent == true)
                {
                    if (fi.Length > CriticalFileBytes)
                    {
                        using (File.Create(newfile)) { }
                    }
                    else
                    {
                        File.Copy(file, newfile);
                    }
                }
                else
                {
                    if (IsNoFile)
                    {
                        using (File.Create(newfile)) { }
                    }
                }
            }
        }
    }
}
