﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using System.IO;
using System.Threading;

namespace AutoFolderMirror
{
    public partial class MainForm : Form
    {
        MirrorHelper MirrorInfo = new MirrorHelper();

        public MainForm()
        {
            InitializeComponent();
        }

        public void alert(string text)
        {
            MessageBox.Show(text);
        }
        private void Form1_Load(object sender, EventArgs e)
        {
            Form.CheckForIllegalCrossThreadCalls = false;
            string Option = new IniHelp().ReadValue("Option");
            string FileBytes = new IniHelp().ReadValue("FileBytes");
            Option1FileBytes.Text = FileBytes;
            switch (Option)
            {
                case "1":
                    Option1.Checked = true;
                    break;
                case "2":
                    Option2.Checked = true;
                    break;
                case "3":
                    Option3.Checked = true;
                    break;
                default:
                    break;
            }
        }
        #region 拖放操作
        private void Form1_DragDrop(object sender, DragEventArgs e)
        {
            string path = ((Array)e.Data.GetData(DataFormats.FileDrop)).GetValue(0).ToString();
            if (Directory.Exists(path))
            {
                SourceDirPath_TextBox.Text = path;
                return;
            }
            if (File.Exists(path))
            {
                FileInfo fi = new FileInfo(path);
                SourceDirPath_TextBox.Text = fi.DirectoryName;
                return;
            }
        }

        private void Form1_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
                e.Effect = DragDropEffects.Link;
            else
                e.Effect = DragDropEffects.None;
        }
        #endregion

        private void button1_Click(object sender, EventArgs e)
        {
            this.Text = "开始";
            string SourceDirPath = SourceDirPath_TextBox.Text.Trim();
            if (!Directory.Exists(SourceDirPath))
            {
                alert("目录不存在");
                return;
            }
            MirrorInfo = new MirrorHelper(SourceDirPath);
            #region 确定哪种模式
            int SelectOption = 0;
            if (Option1.Checked == true)
            {
                SelectOption = 1;
                MirrorInfo.IsCopyContent = true;
                string FileBytes = Option1FileBytes.Text.Trim();
                new IniHelp().WriteValue("FileBytes", FileBytes);
                int criticalFileBytes;
                try
                {
                    criticalFileBytes = Math.Max(1024, Int32.Parse(FileBytes) * 1024);
                }
                catch
                {
                    criticalFileBytes = 1 * 1024;
                }
                MirrorInfo.CriticalFileBytes = criticalFileBytes;
            }
            else if (Option2.Checked == true)
            {
                SelectOption = 2;
                MirrorInfo.IsCopyContent = false;
            }
            else if (Option3.Checked == true)
            {
                SelectOption = 3;
                MirrorInfo.IsCopyContent = false;
                MirrorInfo.IsNoFile = false;
            }
            #endregion
            new IniHelp().WriteValue("Option", SelectOption);
            Thread Mirror = new Thread(MirrorWork);
            Mirror.IsBackground = true;
            Mirror.Start();
        }
        /// <summary>
        /// 克隆进程
        /// </summary>
        private void MirrorWork()
        {
            try
            {
                panel1.Enabled = false;
                MirrorInfo.Mirror(TargetDirPath_TextBox.Text);
                DialogResult dr = MessageBox.Show("镜像完毕,是否立刻打开克隆的文件夹？", "对话框标题", MessageBoxButtons.OKCancel, MessageBoxIcon.Question);
                if (dr == DialogResult.OK)
                {
                    System.Diagnostics.Process.Start("explorer", "" + MirrorInfo.CurrTargetDirPath);
                }
            }
            catch (Exception e)
            {
                alert(e.Message);
            }
            finally
            {
                panel1.Enabled = true;
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void textBox2_TextChanged(object sender, EventArgs e)
        {
            dirUserControl1.ClipReplace = textBox2.Text;
        }

        public void MouseDoubleClick()
        {
            // Declares an IDataObject to hold the data returned from the clipboard.
            // Retrieves the data from the clipboard.
            IDataObject iData = Clipboard.GetDataObject();

            // Determines whether the data is in a format you can use.
            if (iData.GetDataPresent(DataFormats.Text))
            {
                // Yes it is, so display it in a text box.
                string ClipText = ((String)iData.GetData(DataFormats.Text));
                if (!string.IsNullOrEmpty(ClipText))
                {
                    textBox2.Text = ClipText;
                }
            }
        }
        private void textBox2_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            MouseDoubleClick();
        }

        private void dirUserControl1_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            MouseDoubleClick();
        }

        private void dirUserControl1_Load(object sender, EventArgs e)
        {

        }

        private void textBox1_TextChanged(object sender, EventArgs e)
        {
            try
            {
                DirectoryInfo Source = new DirectoryInfo(SourceDirPath_TextBox.Text.Trim());
                TargetDirPath_TextBox.Text = Source.Parent.FullName;
            }
            catch (Exception)
            {
                TargetDirPath_TextBox.Text = "";
            }
        }
        private FolderBrowserDialog dialog = new FolderBrowserDialog();
        private void selectbutton1_Click(object sender, EventArgs e)
        {
            dialog.Description = "请选择需要克隆的文件夹";
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                if (!string.IsNullOrEmpty(dialog.SelectedPath))
                {
                    SourceDirPath_TextBox.Text = dialog.SelectedPath;
                }
            }
        }

        private void selectbutton2_Click(object sender, EventArgs e)
        {
            dialog.Description = "请选择需要克隆的文件夹";
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                if (!string.IsNullOrEmpty(dialog.SelectedPath))
                {
                    TargetDirPath_TextBox.Text = dialog.SelectedPath;
                }
            }
        }

       
    }
}
